==> bobcat_3.19.01.orig.tar.gz: bobcat-3.19.01/exception/driver/driver.cc <==
#include <iostream>
#include "../exception"

#include <fstream>
#include <cerrno>

#include <cstring>

using namespace std;
using namespace FBB;


int main(int argc, char **argv)
{
    string hello = "hello world";

    try
    {
        try
        {                               // throw exception in which data of
                                        // various types were inserted
            throw Exception() << hello << ' ' << 12.34 << "...";
        }
        catch(exception const &e)
        {
            cerr << e.what() << '\n';
            throw;                      // may be rethrown, which is standard
        }
    }
    catch(exception const &e)
    {
        cout << "Exception caught: " << e.what() << '\n';
    }

    try
    {                               // throw exception in which data of
                                    // various types were inserted
        throw Exception(5) << "Exception with errno value set";
    }
    catch(exception const &e)
    {
        cerr << e.what() << '\n'
             << "Errno == " << errno << '\n';
    }

    try
    {
        ofstream out;
        Exception::open(out, "out");

        Exception::open(out, "");
    }
    catch(exception const &e)
    {
        cout << e.what() << '\n';
    }

    try
    {
        ofstream out;
        Exception::open(out, "out", ios::in | ios::out);
    }
    catch(exception const &e)
    {
        cout << e.what() << '\n';
    }

    try
    {
        throw Exception(E2BIG) << "Error: " << FBB::strerror;
    }
    catch(exception const &e)
    {
        cout << e.what() << '\n';
    }
}

==> bobcat_5.00.02.orig.tar.gz: bobcat-5.00.02/exception/driver/driver.cc <==
#include <iostream>
#include "../exception"

#include <fstream>
#include <cerrno>

#include <cstring>

using namespace std;
using namespace FBB;


int main(int argc, char **argv)
{
    string hello = "hello world";

    try
    {
        try
        {                               // throw exception in which data of
                                        // various types were inserted
            throw Exception() << hello << ' ' << 12.34 << "...";
        }
        catch(exception const &e)
        {
            cerr << "first: " << e.what() << '\n';
            throw;                      // may be rethrown, which is standard
        }
    }
    catch(exception const &e)
    {
        cout << "second: exception caught: " << e.what() << '\n';
    }

    try
    {                               // throw exception in which data of
                                    // various types were inserted
        throw Exception(5) << "third: exception with errno value set";
    }
    catch(exception const &e)
    {
        cerr << "fourth: " << e.what() << '\n'
             << "Exception == " << errno << '\n';
    }

    try
    {
        ofstream out;
        Exception::open(out, "out");

        Exception::open(out, "");
    }
    catch(exception const &e)
    {
        cout << "fifth: " << e.what() << '\n';
    }

    try
    {
        ofstream out;
        Exception::open(out, "out", ios::in | ios::out);
    }
    catch(exception const &e)
    {
        cout << "sixth: " << e.what() << '\n';
    }

    try
    {
        throw Exception(E2BIG) << "Error: " << FBB::errnodescr;
    }
    catch(exception const &e)
    {
        cout << "eighth: " << e.what() << '\n';
    }
    
    cout << "end of program\n";
}
